@@ -1,5 +1,5 @@
 package Geo::Coder::OpenCage;
-$Geo::Coder::OpenCage::VERSION = '0.08';
+$Geo::Coder::OpenCage::VERSION = '0.09';
 use strict;
 use warnings;
 
@@ -116,7 +116,7 @@ Geo::Coder::OpenCage
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -216,6 +216,10 @@ All strings passed to and recieved from Geo::Coder::OpenCage methods are expecte
 
 For more information see L<perlunicode>.
 
+=head1 SEE ALSO
+
+This module was featured in the 2016 Perl Advent Calendar. L<Read the article|http://perladvent.org/2016/2016-12-08.html>.
+
 =head1 AUTHOR
 
 Ed Freyfogle 
